[![](https://live.staticflickr.com/65535/52193681450_5c81810ec3_b.png)](https://live.staticflickr.com/65535/52193681450_5c81810ec3_o.png)

<!-- INFO BADGES -->  


[![](https://img.shields.io/pypi/pyversions/lasair)](https://pypi.org/project/lasair/)  
[![](https://img.shields.io/pypi/v/lasair)](https://pypi.org/project/lasair/)  
[![](https://img.shields.io/github/license/lsst-uk/lasair_api)](https://github.com/lsst-uk/lasair_api)  
[![](https://img.shields.io/pypi/dm/lasair)](https://pypi.org/project/lasair/)  


<!-- STATUS BADGES -->  

<!--  [![](http://157.245.42.153:8080/buildStatus/icon?job=lasair%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/lasair/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=lasair%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/lasair/activity?branch=develop) 
[![](https://cdn.jsdelivr.net/gh/lsst-uk/lasair_api@master/coverage.svg)](https://raw.githack.com/lsst-uk/lasair_api/master/htmlcov/index.html)    -->
[![](https://readthedocs.org/projects/lasair/badge/?version=master)](https://lasair.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/lsst-uk/lasair_api/type:%20bug?label=bug%20issues)](https://github.com/lsst-uk/lasair_api/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

# Lasair. A UK Alert Stream Broker and Transient Science Platform.

*Lasair* is being developed by The University of Edinburgh and Queen\'s University Belfast with the ultimate goal of serving transient alerts from the future [Rubin Legacy Survey of Space and Time (LSST)](https://www.lsst.org) to the astronomical community. *Lasair* (pronounced '*L-AH-s-uh-r*') means flame or flash in Scots and Irish gaelic. To prototype functionality needed to process transient event alerts from LSST, Lasair is currently processing and serving data from the public stream of the [Zwicky Transient Facility (ZTF)](http://www.ztf.caltech.edu/), which is releasing a transient alert stream in a format similar to that envisaged for LSST. We thank ZTF for access to this valuable public data stream.

If you make use of Lasair in any of your work, please remember to cite our paper: 

> *[Lasair: The Transient Alert Broker for LSST:UK](https://doi.org/10.3847/2515-5172/ab020f)*, K. W. Smith, R. D. Williams et. al., Research Notes AAS, **3**,26 (2019).

Documentation for Lasair is hosted on [Read the Docs](https://lasair.readthedocs.io/en/main/). The code lives on [github](https://github.com/orgs/lsst-uk/repositories?q=lasair&type=all&language=&sort=). 





